pilas.video

Package pilas :: Package video |
[hide private]
[frames] | no frames]

# Package video

source code

import video import pilas

todos = []

from video import DeCamara from video import DePelicula

Submodules | [hide private]
pilas.video.video: import pilas try: import opencv from opencv import highgui except ImportError: opencv = None pilas.video.webcam: import pilas try: import Image import opencv from opencv import highgui

Variables | [hide private]
| __package__ = `None` hash(x)